%
% This script shows how to perform a correspondence analysis
% with matlab
% This script calls 2 functions
% corresp and afc_sup
% 
% the example used here is from
% the related paper: 
%  Abdi, H. & Williams, L.J. (2010). Correspondence analysis. 
%  In N.J. Salkind, D.M., Dougherty, & B. Frey (Eds.):  
%  Encyclopedia of Research Design. Thousand Oaks (CA): Sage
%  herve@utdallas.edu      www.utdallas.edu/~herve
%
%  


% Script: Test the CA example
% for the punctuation and author example
%
% first clear the memory
clear
% this is the main data 
% an I=6 rows    (French authors)
% by J=3 columns (punctuation marks)
X=[ 7836  13112   6026
   53655 102383  42413
  115615 184541  59226
  161926 340479  62754
   38177 105101  12670
   46371  58367 14299];





% name of the rows (French authors)
nom_row(1,1)={' Rousseau'};
nom_row(2,1)={' Chateaubriand'};
nom_row(3,1)={' Hugo'};
nom_row(4,1)={' Zola'};
nom_row(5,1)={' Proust'};
nom_row(6,1)={' Giraudoux'};

% names of the columns (punctuation marks)
nom_col(1,1)={' *PERIOD'};
nom_col(2,1)={' *COMMA'};
nom_col(3,1)={' *OTHER'};


% Now call the function that computes the CA
% for the active table (X)
[lambda,tau,d2,Fi,Ri,Ctri,d2j,Fj,Rj,Ctrj]=corresp(X);
% See help of corresp for explanation of what is what up there



% Here we show to compute (i.e., project) 
% the factor scores for supplementary (i.e., illustrative)
% rows and columns

%  Add A set of supplementary columns
%  The columns are in the matrix sup_col
%  The call to the routine afc_sup should
%  be done with:
%        lambda (the eigenvalues)
%        the coordinates of the other set
%        (i.e. for sup row go use the column coordinates)
%        they should be in the correct format
%        i.e. the profile are always computed as
%        rows
% 
%  The sup columns are the "Other Marks"
% Exclamation interrogation semicolon colon  
sup_col=[413        1240        3401         972
        4669        4595       19354       13795
       19513        9876       22585        7252
       24025       10665       18391        9673
        2756        2448        3850        3616
        5893        5042        1946        1418];
% Name of the  supplementary Columns
nom_colsup(1,1)={'* Exclamation'};
nom_colsup(2,1)={'* Interrogation'};
nom_colsup(3,1)={'* Semicolon'};
nom_colsup(4,1)={'* Colon'};
% Compute the sup col NB sup_col' to call because 
%   the routine assumes one wants to compute sup. rows
 fj_sup=afc_sup(sup_col',Fi,lambda);

 
%  Now add a supplementary row  
%  This is  H.A. Reseau de neurones. Chap 1
sup_row=[ 216 139 26];
% The name of the supplementary row
nom_rowsup(1,1)={'* Abdi'};
% call afc_sup
fi_sup=afc_sup(sup_row,Fj,lambda);



% Done 
disp(['All Done'])
